aboutsummaryrefslogtreecommitdiff
path: root/video/avi_decoder.h
diff options
context:
space:
mode:
authorEugene Sandulenko2011-01-23 19:08:09 +0000
committerEugene Sandulenko2011-01-23 19:08:09 +0000
commitcaa6684752a310e916b179125a4125a8b3be36f0 (patch)
treedc364d58619b297194bc5d0673b694c34fb51b6c /video/avi_decoder.h
parent3d15871ee2d6a9c0ce4819a6ab5925638bafa8b9 (diff)
downloadscummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.tar.gz
scummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.tar.bz2
scummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.zip
VIDEO: Move video classes to Video:: namespace
svn-id: r55479
Diffstat (limited to 'video/avi_decoder.h')
-rw-r--r--video/avi_decoder.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/video/avi_decoder.h b/video/avi_decoder.h
index a89b378c10..57a39ea941 100644
--- a/video/avi_decoder.h
+++ b/video/avi_decoder.h
@@ -31,7 +31,7 @@
#include "sound/audiostream.h"
#include "sound/mixer.h"
-namespace Graphics {
+namespace Video {
#define UNKNOWN_HEADER(a) error("Unknown header found -- \'%s\'", tag2str(a))
@@ -182,8 +182,8 @@ public:
uint16 getHeight() const { return _header.height; }
uint32 getFrameCount() const { return _header.totalFrames; }
uint32 getElapsedTime() const;
- const Surface *decodeNextFrame();
- PixelFormat getPixelFormat() const;
+ const Graphics::Surface *decodeNextFrame();
+ Graphics::PixelFormat getPixelFormat() const;
const byte *getPalette() { _dirtyPalette = false; return _palette; }
bool hasDirtyPalette() const { return _dirtyPalette; }
@@ -220,6 +220,6 @@ private:
void queueAudioBuffer(uint32 chunkSize);
};
-} // End of namespace Graphics
+} // End of namespace Video
#endif